@@ -1,5 +1,6 @@
 use std::iter;
 
+use serde::Deserialize;
 use swc_common::{util::take::Take, Spanned, DUMMY_SP};
 use swc_ecma_ast::*;
 use swc_ecma_transforms_base::{helper, perf::Check};
@@ -35,14 +36,27 @@ use swc_trace_macro::swc_trace;
 /// });
 /// ```
 #[tracing::instrument(level = "trace", skip_all)]
-pub fn async_to_generator() -> impl Fold + VisitMut {
-    as_folder(AsyncToGenerator)
+pub fn async_to_generator(c: Config) -> impl Fold + VisitMut {
+    as_folder(AsyncToGenerator { c })
+}
+
+#[derive(Debug, Clone, Copy, Default, Deserialize)]
+#[serde(rename_all = "camelCase")]
+pub struct Config {
+    #[serde(default)]
+    pub ignore_function_name: bool,
+    #[serde(default)]
+    pub ignore_function_length: bool,
 }
 
 #[derive(Default, Clone)]
-struct AsyncToGenerator;
+struct AsyncToGenerator {
+    c: Config,
+}
 
 struct Actual {
+    c: Config,
+
     extra_stmts: Vec<Stmt>,
     hoist_stmts: Vec<Stmt>,
 }
@@ -72,6 +86,7 @@ impl AsyncToGenerator {
 
         for mut stmt in stmts.drain(..) {
             let mut actual = Actual {
+                c: self.c,
                 extra_stmts: vec![],
                 hoist_stmts: vec![],
             };
@@ -149,6 +164,8 @@ impl VisitMut for Actual {
         }
 
         let mut wrapper = FunctionWrapper::from(f.take());
+        wrapper.ignore_function_name = self.c.ignore_function_name;
+        wrapper.ignore_function_length = self.c.ignore_function_length;
 
         let fn_expr = wrapper.function.fn_expr().unwrap();
 
@@ -166,6 +183,8 @@ impl VisitMut for Actual {
                 if let DefaultDecl::Fn(expr) = &mut export_default.decl {
                     if expr.function.is_async {
                         let mut wrapper = FunctionWrapper::from(expr.take());
+                        wrapper.ignore_function_name = self.c.ignore_function_name;
+                        wrapper.ignore_function_length = self.c.ignore_function_length;
 
                         let fn_expr = wrapper.function.fn_expr().unwrap();
 
@@ -295,6 +314,8 @@ impl Actual {
                 self.hoist_stmts.extend(state.to_stmt());
 
                 let mut wrapper = FunctionWrapper::from(arrow_expr.take());
+                wrapper.ignore_function_name = self.c.ignore_function_name;
+                wrapper.ignore_function_length = self.c.ignore_function_length;
                 wrapper.binding_ident = binding_ident;
 
                 let fn_expr = wrapper.function.expect_fn_expr();
@@ -310,6 +331,8 @@ impl Actual {
                 },
             ) => {
                 let mut wrapper = FunctionWrapper::from(fn_expr.take());
+                wrapper.ignore_function_name = self.c.ignore_function_name;
+                wrapper.ignore_function_length = self.c.ignore_function_length;
                 wrapper.binding_ident = binding_ident;
 
                 let fn_expr = wrapper.function.expect_fn_expr();
