@@ -147,20 +147,6 @@ impl Take for ClassExtra {
 impl VisitMut for ClassProperties {
     noop_visit_mut_type!();
 
-    fn visit_mut_ident(&mut self, i: &mut Ident) {
-        i.optional = false;
-    }
-
-    fn visit_mut_array_pat(&mut self, p: &mut ArrayPat) {
-        p.visit_mut_children_with(self);
-        p.optional = false;
-    }
-
-    fn visit_mut_object_pat(&mut self, p: &mut ObjectPat) {
-        p.visit_mut_children_with(self);
-        p.optional = false;
-    }
-
     fn visit_mut_module_items(&mut self, n: &mut Vec<ModuleItem>) {
         self.visit_mut_stmt_like(n);
 
@@ -174,8 +160,6 @@ impl VisitMut for ClassProperties {
     }
 
     fn visit_mut_block_stmt_or_expr(&mut self, body: &mut BlockStmtOrExpr) {
-        let span = body.span();
-
         match body {
             BlockStmtOrExpr::Expr(expr) if expr.is_class() => {
                 let ClassExpr { ident, class } = expr.take().class().unwrap();
@@ -191,7 +175,10 @@ impl VisitMut for ClassProperties {
                     arg: Some(Box::new(Expr::Ident(ident))),
                 }));
 
-                *body = BlockStmtOrExpr::BlockStmt(BlockStmt { span, stmts });
+                *body = BlockStmtOrExpr::BlockStmt(BlockStmt {
+                    span: DUMMY_SP,
+                    stmts,
+                });
             }
             _ => body.visit_mut_children_with(self),
         };
@@ -974,24 +961,6 @@ struct ShouldWork {
 impl Visit for ShouldWork {
     noop_visit_type!();
 
-    fn visit_ident(&mut self, n: &Ident) {
-        if n.optional {
-            self.found = true;
-        }
-    }
-
-    fn visit_array_pat(&mut self, n: &ArrayPat) {
-        if n.optional {
-            self.found = true;
-        }
-    }
-
-    fn visit_object_pat(&mut self, n: &ObjectPat) {
-        if n.optional {
-            self.found = true;
-        }
-    }
-
     fn visit_class_method(&mut self, _: &ClassMethod) {
         self.found = true;
     }
