@@ -930,7 +930,7 @@ expect(v.next()).toEqual({ done: true });
 test_exec!(
     syntax(),
     |t| chain!(
-        es2017(),
+        es2017(Default::default()),
         es2016(),
         es2015(
             Mark::fresh(Mark::root()),
@@ -949,7 +949,7 @@ test_exec!(
 test_exec!(
     syntax(),
     |_| chain!(
-        async_to_generator(),
+        async_to_generator(Default::default()),
         es2015::for_of(Default::default()),
         es2015::regenerator(Default::default(), Mark::fresh(Mark::root())),
     ),
@@ -1074,7 +1074,7 @@ expect(v.next()).toEqual({ done: false, value: 'Error'});
 
 test_exec!(
     Syntax::default(),
-    |_| chain!(async_to_generator(), tr(())),
+    |_| chain!(async_to_generator(Default::default()), tr(())),
     issue_1036_1,
     "
     const x = async function() {
@@ -1157,7 +1157,7 @@ test_exec!(
 
 test_exec!(
     Syntax::default(),
-    |_| chain!(async_to_generator(), tr(())),
+    |_| chain!(async_to_generator(Default::default()), tr(())),
     issue_1125_1,
     "
     async function test() {
@@ -1205,7 +1205,7 @@ function foo() {
 
 test_exec!(
     Syntax::default(),
-    |_| chain!(async_to_generator(), tr(())),
+    |_| chain!(async_to_generator(Default::default()), tr(())),
     hoist_function_in_async_issue_2556_2,
     "
 async function foo() {
@@ -1231,7 +1231,7 @@ return foo()
 
 test!(
     Syntax::default(),
-    |_| chain!(async_to_generator(), tr(())),
+    |_| chain!(async_to_generator(Default::default()), tr(())),
     hoist_function_in_async_issue_2556_4,
     r#"
 function requester() {
@@ -1299,7 +1299,7 @@ function requester() {
 
 test_exec!(
     Syntax::default(),
-    |_| chain!(async_to_generator(), tr(())),
+    |_| chain!(async_to_generator(Default::default()), tr(())),
     hoist_function_in_async_issue_2556_5,
     r#"
 function requester() {
@@ -1321,7 +1321,7 @@ function requester() {
 
 test_exec!(
     Syntax::default(),
-    |_| chain!(async_to_generator(), tr(())),
+    |_| chain!(async_to_generator(Default::default()), tr(())),
     issue_2620,
     r#"
 async function main() {
@@ -1377,7 +1377,7 @@ return main().then((results) => {
 
 test!(
     Syntax::default(),
-    |_| chain!(async_to_generator(), tr(())),
+    |_| chain!(async_to_generator(Default::default()), tr(())),
     hoist_function_in_async_issue_2556_6,
     r#"
 async function foo(a) {
@@ -1451,7 +1451,7 @@ foo(1)
 
 test_exec!(
     Syntax::default(),
-    |_| chain!(async_to_generator(), tr(())),
+    |_| chain!(async_to_generator(Default::default()), tr(())),
     hoist_function_in_async_issue_2556_7,
     r#"
 async function foo(a) {
@@ -1472,7 +1472,7 @@ return foo(1)
 
 test!(
     Syntax::default(),
-    |_| chain!(async_to_generator(), tr(())),
+    |_| chain!(async_to_generator(Default::default()), tr(())),
     hoist_function_in_async_issue_2556_8,
     r#"
 var fib = function fib() {
@@ -1709,7 +1709,7 @@ test!(
 
 test!(
     Syntax::default(),
-    |_| chain!(async_to_generator(), tr(())),
+    |_| chain!(async_to_generator(Default::default()), tr(())),
     issue_1799_1,
     "
     export default function Foo() {
@@ -1745,7 +1745,7 @@ test!(
     |_| {
         let mark = Mark::fresh(Mark::root());
         chain!(
-            async_to_generator(),
+            async_to_generator(Default::default()),
             es2015::<SingleThreadedComments>(mark, None, Default::default())
         )
     },
@@ -1784,7 +1784,7 @@ test!(
     |_| {
         let mark = Mark::fresh(Mark::root());
         chain!(
-            async_to_generator(),
+            async_to_generator(Default::default()),
             es2016(),
             es2015::<SingleThreadedComments>(mark, None, Default::default()),
         )
@@ -1827,7 +1827,7 @@ test!(
             es2022(Default::default()),
             es2021(),
             es2018(Default::default()),
-            es2017(),
+            es2017(Default::default()),
             es2016(),
             es2015::<SingleThreadedComments>(mark, None, Default::default()),
         )
@@ -2087,7 +2087,7 @@ test_exec!(
     |_| {
         let mark = Mark::fresh(Mark::root());
         chain!(
-            async_to_generator(),
+            async_to_generator(Default::default()),
             es2015::for_of(Default::default()),
             regenerator(Default::default(), mark)
         )
