@@ -1,5 +1,5 @@
 var _foo = new WeakSet();
-let Foo = function() {
+let Foo = /*#__PURE__*/ function() {
     "use strict";
     function Foo() {
         _classCallCheck(this, Foo);
