@@ -1,5 +1,5 @@
 var _foo = new WeakMap();
-let Foo = function() {
+let Foo = /*#__PURE__*/ function() {
     "use strict";
     function Foo() {
         _classCallCheck(this, Foo);
@@ -12,7 +12,7 @@ let Foo = function() {
         {
             key: "test",
             value: function test() {
-                let Nested = function() {
+                let Nested = /*#__PURE__*/ function() {
                     function Nested() {
                         _classCallCheck(this, Nested);
                     }
